==> manage-1.1.32-1.jar: management/sqls/营收/报表管理/收费类/收费汇总表/manageGetUsertypeSql.sql <==

 	--用户类型 f_user_type,付款方式 f_payment,用气性质 f_gasproperties,收费笔数 c,应交气量 f_pregas,应交金额 f_preamount,实交金额 f_collection
select f_payment,f_user_type
     from (
     --拿收费记录（不拿同一天冲正的记录）
    select f_user_type,f_payment,f_gasproperties,count(id) c,isnull(sum(f_pregas),0) f_pregas,isnull(SUM(f_preamount),0) f_preamount,
       isnull(sum(f_collection),0) f_collection
      from t_sellinggas
      where f_delivery_date>='{startDate}' and f_delivery_date <='{endDate}' and
       f_charge_state != '无效' and  f_orgstr like '{filialeCodeStr}%'
       and id not in (
       select f_correct_id from t_correctrecord where f_correct_date>='{startDate}'
       and f_correct_date <='{endDate}' and
       f_orgstr like '{filialeCodeStr}%'
       )
    group by  f_user_type,f_payment,f_gasproperties
     union all
	--拿往期冲正金额
			select u1.f_user_type,u1.f_payment,u1.f_gasproperties,(0-COUNT(*)) c,isnull(sum(u1.f_correct_gas),0) f_pregas,
	isnull(sum(u1.f_correct_money),0) f_preamount,
    isnull(sum(u1.f_correct_collection),0) f_collection from (
		select m2.f_user_type,m2.f_payment,m2.f_gasproperties,m1.* from (
		select f_correct_id,f_correct_gas,f_correct_money,
		f_correct_collection  from t_correctrecord
		where f_correct_date>='{startDate}' and  f_correct_date<='{endDate}'
		and f_orgstr like '{filialeCodeStr}%'
		) m1
		left join t_sellinggas m2 on m1.f_correct_id=m2.id
	) u1
	 left join (
	select id from t_sellinggas where
	f_delivery_date>='{startDate}'
 and f_delivery_date<='{endDate}' and f_orgstr like '{filialeCodeStr}%'
	) u2 on u1.f_correct_id=u2.id where u2.id is null
    group by f_user_type,f_payment,f_gasproperties
 ) s group by f_payment,f_user_type

==> manage-1.2.39.jar: management/sqls/营收/报表管理/收费类/收费汇总表/manageGetUsertypeSql.sql <==

 	--用户类型 f_user_type,付款方式 f_payment,用气性质 f_gasproperties,收费笔数 c,应交气量 f_pregas,应交金额 f_preamount,实交金额 f_collection
select f_payment,f_user_type
     from (
     --拿收费记录（不拿同一天冲正的记录）
    select f_user_type,f_payment,f_gasproperties,count(id) c,isnull(sum(f_pregas),0) f_pregas,isnull(SUM(f_preamount),0) f_preamount,
       isnull(sum(f_collection),0) f_collection
      from t_sellinggas
      where f_delivery_date>='{startDate}' and f_delivery_date <='{endDate}' and
       f_charge_state != '无效' and  f_orgstr like '{filialeCodeStr}%'
       and id not in (
       select f_correct_id from t_correctrecord where f_correct_date>='{startDate}'
       and f_correct_date <='{endDate}' and
       f_orgstr like '{filialeCodeStr}%'
       )
    group by  f_user_type,f_payment,f_gasproperties
     union all
	--拿往期冲正金额
	select u2.f_user_type,u2.f_payment,u2.f_gasproperties,(0-COUNT(*)) c,isnull(sum(u1.f_correct_gas),0) f_pregas,
	isnull(sum(u1.f_correct_money),0) f_preamount,
    isnull(sum(u1.f_correct_collection),0) f_collection from (
	select f_correct_id,f_correct_gas,f_correct_money,f_correct_collection  from t_correctrecord where f_correct_date>='{startDate}' and  f_correct_date<='{endDate}'
	and   f_orgstr like '{filialeCodeStr}%') u1
	left join (
	select f_user_type,f_payment,f_gasproperties,id from t_sellinggas where
	f_delivery_date<'{startDate}' and f_charge_state!='无效'
	) u2 on u1.f_correct_id=u2.id where u2.id is not null
    group by f_user_type,f_payment,f_gasproperties
 ) s group by f_payment,f_user_type
